# AGNI Inference Package
Inferring planet properties using AGNI as a static structure model.

## Get started
1. Install Python 3.12 and a distribution of conda
2. `pip install -e .`
3. `inferagni infer "L 98-59 d"`

### Quick links
* AGNI repo: https://github.com/nichollsh/AGNI/
* AGNI docs: https://www.h-nicholls.space/AGNI/
* Zalmoxis docs: https://proteus-framework.org/Zalmoxis/
* Paper: https://www.overleaf.com/project/6853d410bda854791be86cd7

Available under GPLv3. Copyright (c) 2026 Harrison Nicholls.

